# Folder Organizer

A simple open-source folder organizer

![Image](folder-organizer/resources/images/program.png "Image")
![Image](folder-organizer/resources/images/program_with_menu.png "Image")

***

Project developed with [@abelnd](https://github.com/abelnd)
